# RefundFinanceInformationTransferredToAccounting

Whether the refund was transferred to an external accounting system. Use this field for integration with accounting systems, such as NetSuite.  

## Enum

* `PROCESSING` (value: `'Processing'`)

* `YES` (value: `'Yes'`)

* `NO` (value: `'No'`)

* `ERROR` (value: `'Error'`)

* `IGNORE` (value: `'Ignore'`)

[[Back to Model list]](../README.md#documentation-for-models) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to README]](../README.md)


